class DataEntry {
    key;
    value;
    constructor(key, value) {
        this.key = key;
        this.value = value;
    }
}
class Data {
    entries = [];
    constructor(formFields) {
        this.entries = this.createEntries(formFields);
        this.linkEntriesToFormFields(formFields);
    }
    /*
    * Create entries based on the form fields.
    */
    createEntries(formFields) {
        let entries = [];
        for (let [key, field] of Object.entries(formFields)) {
            // Skip html fields
            if (field.type === 'html') {
                continue;
            }
            let entry = {
                key: field.key,
                value: null
            };
            if (field.value) {
                entry.value = field.value;
            }
            // Exeption for textareas: The value has to be an empty string. (Bug from Svelte Material UI)
            else if (field.textarea) {
                entry.value = '';
            }
            else if (field.type === 'checkbox' && field.options !== undefined) {
                entry.value = [];
            }
            entries.push(entry);
        }
        return entries;
    }
    /*
    * Link array index of dataInstance entries to the form fields for value binding.
    */
    linkEntriesToFormFields(formFields) {
        for (let [key, field] of Object.entries(formFields)) {
            // Skip html fields
            if (field.type === 'html') {
                continue;
            }
            field.dataIndex = this.entries.findIndex((entry) => entry.key === field.key);
        }
    }
    toJson() {
        let json = {};
        this.entries.forEach((entry) => {
            json[entry.key] = entry.value;
        });
        return json;
    }
}
export { DataEntry, Data };
